jQuery(function ($) {
    jQuery.validator.setDefaults({
        success: "valid"
    });
    jQuery.validator.addMethod("validate_csv", function (value, element, options) {
        if (!$('#modeCsv:checked').val()) {
            return true;
        }
        let filledInputs = $('.csv_input:input').filter((i, element) => {
            return $(element).val().length > 0
        })

        return filledInputs.length === 1;

    }, "Please fill out at least {0} of these fields.");

    //Intro Free Version
    var lpageryIntroShowed = localStorage.getItem('lpagery_intro_showed_free');
    if (!lpageryIntroShowed && window.location.href.includes("lpagery") && lpagery_ajax_object_root.is_free_plan) {
        introJs().setOptions({
            disableInteraction: true,
            showProgress: true,
            showBullets: false,

            steps: [{
                title: 'Welcome to <br>LPagery',
                intro: 'Let us give you a quick tour around so you can start using LPagery!'
            },
                {
                    element: document.querySelector('.template-path-section'),
                    title: 'Step 1-1: Select a Template Page',
                    intro: 'In the <b>first step</b> you will have to choose your template page.',
                    position: 'right',

                },
                {
                    element: document.querySelector('#menu-pages'),
                    title: 'Step 1-2: Creating a template',
                    intro: 'You can use a regular page as template page, you just have to insert certain placeholders. Check out our step-by-step guide on <a href="https://lpagery.io/docs/create-a-template-page/" target="_blank">How to Create a Template Page</a>',
                    position: 'right',

                },


                {
                    element: document.querySelector('.column-left'),
                    title: 'Step 2',
                    intro: 'Next up you have to upload a CSV/XLSX File with your data. Take a look at our tutorial on <a href="https://lpagery.io/docs/set-up-a-csv-file-with-custom-placeholders/">How to set up a CSV File</a>',
                    position: 'right',

                },


                {
                    element: document.querySelector('#docs-link'),
                    title: 'More Information',
                    intro: 'For detailed tutorials and more help, make sure to check out our <a href="https://lpagery.io/documentation/">documentation</a>',
                    position: 'bottom',

                },

                {
                    element: document.querySelector('#pro-link'),
                    title: 'Go Pro!',
                    intro: 'If you want to have full control over the generated pages and use all features, check out our Pro plans:  <a href="https://lpagery.io/pricing/">Go Pro!</a>',
                    position: 'bottom',

                },

            ]
        }).start();
        localStorage.setItem('lpagery_intro_showed_free', true);
    }



    var tabs = $('.tabs');
    var selector = $('.tabs').find('a').length;
    //var selector = $(".tabs").find(".selector");
    var activeItem = tabs.find('.active');
    var activeWidth = activeItem.innerWidth();
    $(".selector").css({
        "left": activeItem.position.left + "px",
        "width": activeWidth + "px"
    });

    $(".tabs").on("click", "a", function (e) {
        e.preventDefault();
        $('.tabs a').removeClass("active");
        $(this).addClass('active');
        var activeWidth = $(this).innerWidth();
        var itemPos = $(this).position();
        $(".selector").css({
            "left": itemPos.left + "px",
            "width": activeWidth + "px"
        });
    });


    $('.page-select').select2({
        ajax: {
            url: lpagery_ajax_object_root.ajax_url,
            data: function (params) {
                return {
                    "_ajax_nonce": lpagery_ajax_object_root.nonce,
                    action: 'lpagery_get_pages',
                    term: params.term
                };

            },
            processResults: function (data) {
                return {
                    results: $.map(JSON.parse(data), function (item) {
                        return {
                            text: item.title,
                            id: item.id
                        }
                    })
                };
            }
        }
    });

    $('.js-example-basic-multiple').select2();


    $('#slug').bind('input keyup', function () {
        var $this = $(this);
        var delay = 300; // 2 seconds delay after last input

        clearTimeout($this.data('timer'));
        $this.data('timer', setTimeout(function () {
            $this.removeData('timer');
            refreshSlug();
            // Do your stuff after 2 seconds of last user input
        }, delay));
    });

    $('#parent_path').on('change', function (e) {
        refreshSlug();
    })

    $('#template_path').on('change', function (e) {
        let slug = $('#slug');
        let selectedName = $("#template_path option:selected").text();
        if (!slug.val() || lpagery_ajax_object_root.is_free_plan) {
            var ajaxData = {
                action: 'lpagery_custom_sanitize_title',
                slug: encodeURIComponent(selectedName),
                "_ajax_nonce": lpagery_ajax_object_root.nonce
            };
            jQuery.get(
                lpagery_ajax_object_root.ajax_url,
                ajaxData,
                function (response) {
                    slug.val(response)
                    refreshSlug();
                }
            );
        }

    })

    function handleError(e) {
        console.log(e);
        $.modal.close();
        $.toggleRotating($('#next'), false)
        $('#error_span').show();
    }

    function handleCsv(file) {
        var reader = new FileReader();
        reader.readAsText(file);
        reader.onload = function (e) {
            try {
                var csvContent = e.target.result;

                var lines = csvContent.split('\n');
                var headers = lines[0];
                let headersFields = $.getHeaders(headers.split(","));

                var data = [];
                for (var i = 1; i < lines.length; i++) {
                    var line = lines[i];
                    if (line === '') {
                        continue
                    }
                    var currentValues = line.split(",");

                    var currentData = {};
                    for (let j = 0; j < headersFields.length; j++) {
                        currentData[headersFields[j].name] = currentValues[j];
                    }
                    data.push(currentData)
                }
                $.showModal(headersFields, data);
            } catch (e) {
                handleError(e);
            }
        }
    }

    function handleExcel(file) {
        var reader = new FileReader();
        reader.readAsArrayBuffer(file);
        reader.onload = function (e) {
            var fileContent = e.target.result;
            var workbook = XLSX.read(fileContent);
            let jsonSheet = XLSX.utils.sheet_to_json(workbook.Sheets[workbook.SheetNames[0]]);

            var firstElement = jsonSheet[0];
            let headersFields = $.getHeaders(Object.keys(firstElement));
            $.showModal(headersFields, jsonSheet);
        }
    }

    $('#next').on('click', function () {
        $('#error_span').hide();
        try {

            let lpageryForm = $('#lpageryform');
            let valid = lpageryForm.validate({
                errorPlacement: function (error, element) {
                    console.log(error)
                    if (element.attr("name") == "template_path")
                        error.insertAfter("#template_error");

                    if (element.attr("name") == "lat")
                        error.insertAfter("#location_error");
                    if (element.attr("name") == "upload_csv" || element.attr("name") == "validate_csv")
                        error.insertAfter("#location_error");
                    if (element.attr("name") == "slug") {
                        error.insertAfter("#slug_preview")
                    }
                },
                rules: {
                    lat: {
                        required: '#modeRadius:checked'
                    },
                    google_sheet_url: {
                        validate_csv: true,


                    },
                    upload_csv: {
                        validate_csv: true,

                    }
                }
            }).form()

            if (!valid) {
                return
            }
            $.toggleRotating($('#next'), true)


            let mode = $("input[name$='modeRadio']:checked").val()

            if (mode === 'csv') {
                var file = $('#upload_csv').prop('files')[0];
                if (file) {
                    if (file.name.endsWith('.xlsx') || file.name.endsWith('.xls')) {
                        handleExcel(file);
                    } else {
                        handleCsv(file);
                    }
                }


            } else if (mode === 'location') {
                if ($.fetchCities) {
                    $.fetchCities();
                }
            } else {
                let googleSheetUrl = $('#google_sheet_url').val();
                if (googleSheetUrl && $.fetchGoogleSheet) {
                    $.fetchGoogleSheet();
                }
            }
        } catch (e) {
            handleError(e);
        }
    })

    function refreshSlug() {
        let slugValue = $('#slug').val();
        if (slugValue) {
            var ajaxData = {
                "_ajax_nonce": lpagery_ajax_object_root.nonce,
                action: 'lpagery_fetch_permalink',
                post_id: $('#parent_path').val(),
                slug: slugValue
            };
            jQuery.get(
                lpagery_ajax_object_root.ajax_url,
                ajaxData,
                function (response) {
                    $('#slug_preview').text(response)
                }
            );
        } else {
            $('#slug_preview').text('')
        }
    }

    if (lpagery_ajax_object_root.is_permalink_structure_disabled) {
        $('#slug_disabled').show();
    }

    $('.tabs > a').on("click", function (e) {
        let element = $(this)[0];
        switch (element.id) {
            case "anchor_settings": {
                $.lpagery_load_settings();
                $("#dashboard_container ").hide();
                $("#settings_container").show();
                $("#pro_container").hide();
                $("#presets_container").hide();
                break;
            }
            case "anchor_dashboard": {
                $("#dashboard_container ").show();
                $("#settings_container").hide();
                $("#pro_container").hide();
                $("#presets_container").hide();

                break;
            }
            case "anchor_pro": {
                $("#dashboard_container ").hide();
                $("#settings_container").hide();
                $("#pro_container").show();
                $("#presets_container").hide();

            }
        }
    });
});