<?php

class LPagerySettingsController
{
    static function lpagery_filter_post_type( $type )
    {
        return !in_array( $type, array(
            "post",
            "page",
            "attachment",
            "revision",
            "nav_menu_item",
            "custom_css",
            "customize_changeset",
            "oembed_cache",
            "user_request",
            "wp_block",
            "wp_template",
            "wp_template_part",
            "wp_global_styles",
            "wp_navigation"
        ) );
    }
    
    public static function lpagery_get_post_types()
    {
        return array_filter( get_post_types( array(
            'hierarchical' => true,
        ) ), [ __CLASS__, "lpagery_filter_post_type" ] );
    }
    
    public static function lpagery_save_settings( $spintax, $post_types )
    {
        $settings = array(
            'spintax'           => $spintax,
            'custom_post_types' => $post_types,
        );
        update_user_option(
            get_current_user_id(),
            'lpagery_settings',
            serialize( $settings ),
            false
        );
    }
    
    public static function lpagery_get_settings()
    {
        return json_encode( maybe_unserialize( self::lpagery_get_settings_internal() ) );
    }
    
    public static function lpagery_get_spintax_enabled()
    {
        $settings = unserialize( get_user_option( 'lpagery_settings', get_current_user_id() ) );
        if ( $settings == null ) {
            return filter_var( self::lpagery_get_default_settings()['spintax'], FILTER_VALIDATE_BOOLEAN );
        }
        return filter_var( $settings['spintax'], FILTER_VALIDATE_BOOLEAN );
    }
    
    public static function lpagery_get_selected_custom_post_types()
    {
        $settings = unserialize( get_user_option( 'lpagery_settings', get_current_user_id() ) );
        return filter_var( $settings['custom_post_types'], FILTER_VALIDATE_BOOLEAN );
    }
    
    private static function lpagery_get_settings_internal()
    {
        if ( lpagery_fs()->is_free_plan() ) {
            return self::lpagery_get_default_settings();
        }
        $user_options = get_user_option( 'lpagery_settings', get_current_user_id() );
        return ( $user_options != null ? $user_options : self::lpagery_get_default_settings() );
    }
    
    private static function lpagery_get_default_settings()
    {
        return array(
            "spintax" => false,
        );
    }

}