<?php

require_once plugin_dir_path( __FILE__ ) . '../controller/PageCreator.php';
require_once plugin_dir_path( __FILE__ ) . '../data/LPageryDao.php';
require_once plugin_dir_path( __FILE__ ) . '../controller/CustomSanitizer.php';
require_once plugin_dir_path( __FILE__ ) . '../controller/SettingsController.php';
require_once plugin_dir_path( __FILE__ ) . '../utils/Utils.php';
add_action( 'wp_ajax_lpagery_fetch_permalink', 'lpagery_fetch_permalink' );
function lpagery_fetch_permalink()
{
    check_ajax_referer( 'lpagery_ajax' );
    $post_id = (int) $_GET['post_id'];
    if ( empty($_GET['slug']) ) {
        return false;
    }
    $slug = strtolower( LPageryCustomSanitizer::lpagery_sanitize_title_with_dashes( $_GET['slug'] ) );
    echo  site_url( get_page_uri( $post_id ) . "/" . $slug ) ;
    wp_die();
}

add_action( 'wp_ajax_lpagery_custom_sanitize_title', 'lpagery_custom_sanitize_title' );
function lpagery_custom_sanitize_title()
{
    check_ajax_referer( 'lpagery_ajax' );
    if ( empty($_GET['slug']) ) {
        return false;
    }
    $slug = strtolower( urldecode( LPageryCustomSanitizer::lpagery_sanitize_title_with_dashes( $_GET['slug'] ) ) );
    echo  esc_html( $slug ) ;
    wp_die();
}

add_action( 'wp_ajax_lpagery_generate_posts', 'lpagery_generate_posts' );
function lpagery_generate_posts()
{
    check_ajax_referer( 'lpagery_ajax' );
    try {
        $data = $_POST['data'];
        $data = str_replace( "\\", "", $data );
        $json_decode = json_decode( $data, true );
        $json_decode = array_map( 'sanitize_text_field', $json_decode );
        $templatePath = (int) $_POST['templatePath'];
        if ( empty($templatePath) || empty($data) ) {
            return false;
        }
        $page = get_post( $templatePath );
        $categories = array();
        $status = 'publish';
        $slug = LPageryCustomSanitizer::lpagery_sanitize_title_with_dashes( $page->post_title );
        $parent_path = null;
        $keys = array();
        $values = array();
        foreach ( $json_decode as $key => $value ) {
            array_push( $keys, '{' . $key . '}' );
            array_push( $values, $value );
        }
        LPageryPageCreator::lpagery_create_substituted_page(
            $keys,
            $values,
            $page,
            $parent_path,
            $categories,
            $slug,
            $status
        );
    } catch ( Throwable $exception ) {
        print_r( json_encode( array(
            "success"   => false,
            "exception" => $exception->__toString(),
        ) ) );
        wp_die();
    }
    print_r( json_encode( array(
        "success"   => true,
        "post_type" => $page->post_type,
    ) ) );
    wp_die();
}

add_action( 'wp_ajax_lpagery_save_settings', 'lpagery_save_settings' );
function lpagery_save_settings()
{
    check_ajax_referer( 'lpagery_ajax' );
    $settings = LPageryUtils::sanitize_object( $_POST['settings'] );
    $spintax_enabled = rest_sanitize_boolean( $settings['spintax'] );
    $custom_post_types = $settings['custom_post_types'];
    $custom_post_types = ( isset( $custom_post_types ) ? array_map( 'sanitize_text_field', $custom_post_types ) : array() );
    LPagerySettingsController::lpagery_save_settings( $spintax_enabled, $custom_post_types );
    wp_die();
}

add_action( 'wp_ajax_lpagery_get_settings', 'lpagery_get_settings' );
function lpagery_get_settings()
{
    check_ajax_referer( 'lpagery_ajax' );
    print_r( LPagerySettingsController::lpagery_get_settings() );
    wp_die();
}

function lpagery_map_page( $page )
{
    return array(
        "id"    => $page->ID,
        "title" => $page->post_title,
    );
}

add_action( 'wp_ajax_lpagery_get_pages', 'lpagery_get_pages' );
function lpagery_get_pages()
{
    check_ajax_referer( 'lpagery_ajax' );
    $user_option = unserialize( get_user_option( 'lpagery_settings', get_current_user_id() ) );
    $custom_post_types = (array) $user_option['custom_post_types'];
    array_push( $custom_post_types, "page" );
    $posts = LPageryDao::lpagery_search_posts( ( isset( $_GET['term'] ) ? sanitize_text_field( $_GET['term'] ) : "" ), $custom_post_types );
    print_r( json_encode( array_map( "lpagery_map_page", $posts ) ) );
    wp_die();
}

add_action( 'wp_ajax_lpagery_get_post_type', 'lpagery_get_post_type' );
function lpagery_get_post_type()
{
    check_ajax_referer( 'lpagery_ajax' );
    $post_id = (int) $_GET['post_id'];
    $post = get_post( $post_id );
    echo  esc_html( $post->post_type ) ;
    wp_die();
}
